@@ -32,17 +32,13 @@
 #include "shared.h"
 #include "crc.h"
 
-#define YQ2VERSION "8.20"
+#define YQ2VERSION "8.51"
 #define BASEDIRNAME "baseq2"
 
 #ifndef YQ2OSTYPE
 #error YQ2OSTYPE should be defined by the build system
 #endif
 
-#ifndef YQ2ARCH
-#error YQ2ARCH should be defined by the build system
-#endif
-
 #ifndef BUILD_DATE
 #define BUILD_DATE __DATE__
 #endif
@@ -57,6 +53,36 @@
  #endif
 #endif
 
+#ifndef YQ2ARCH
+  #ifdef _MSC_VER
+    // Setting YQ2ARCH for VisualC++ from CMake doesn't work when using VS integrated CMake
+    // so set it in code instead
+    #ifdef YQ2ARCH
+      #undef YQ2ARCH
+    #endif
+    #ifdef _M_X64
+      // this matches AMD64 and ARM64EC (but not regular ARM64), but they're supposed to be binary-compatible somehow, so whatever
+      #define YQ2ARCH "x86_64"
+    #elif defined(_M_ARM64)
+      #define YQ2ARCH "arm64"
+    #elif defined(_M_ARM)
+      #define YQ2ARCH "arm"
+    #elif defined(_M_IX86)
+      #define YQ2ARCH "x86"
+    #else
+      // if you're not targeting one of the aforementioned architectures,
+      // check https://learn.microsoft.com/en-us/cpp/preprocessor/predefined-macros
+      // to find out how to detect yours and add it here - and please send a patch :)
+      #error "Unknown CPU architecture!"
+      // (for a quick and dirty solution, comment out the previous line, but keep in mind
+      //  that savegames may not be compatible with other builds of Yamagi Quake II)
+      #define YQ2ARCH "UNKNOWN"
+    #endif // _M_X64 etc
+  #else // other compilers than MSVC
+    #error YQ2ARCH should be defined by the build system
+  #endif // _MSC_VER
+#endif // YQ2ARCH
+
 /* ================================================================== */
 
 typedef struct sizebuf_s
@@ -141,7 +167,7 @@ void COM_AddParm(char *parm);
 void COM_Init(void);
 void COM_InitArgv(int argc, char **argv);
 
-char *CopyString(char *in);
+char *CopyString(const char *in);
 
 /* ================================================================== */
 
@@ -422,27 +448,27 @@ void Cmd_ForwardToServer(void);
 
 extern cvar_t *cvar_vars;
 
-cvar_t *Cvar_Get(char *var_name, char *value, int flags);
+cvar_t *Cvar_Get(const char *var_name, const char *value, int flags);
 
 /* creates the variable if it doesn't exist, or returns the existing one */
 /* if it exists, the value will not be changed, but flags will be ORed in */
 /* that allows variables to be unarchived without needing bitflags */
 
-cvar_t *Cvar_Set(char *var_name, char *value);
+cvar_t *Cvar_Set(const char *var_name, const char *value);
 
 /* will create the variable if it doesn't exist */
 
-cvar_t *Cvar_ForceSet(char *var_name, char *value);
+cvar_t *Cvar_ForceSet(const char *var_name, char *value);
 
 /* will set the variable even if NOSET or LATCH */
 
-cvar_t *Cvar_FullSet(char *var_name, char *value, int flags);
+cvar_t *Cvar_FullSet(const char *var_name, const char *value, int flags);
 
-void Cvar_SetValue(char *var_name, float value);
+void Cvar_SetValue(const char *var_name, float value);
 
 /* expands value to a string and calls Cvar_Set */
 
-float Cvar_VariableValue(char *var_name);
+float Cvar_VariableValue(const char *var_name);
 
 /* returns 0 if not defined or non numeric */
 
@@ -465,7 +491,7 @@ qboolean Cvar_Command(void);
 /* command.  Returns true if the command was a variable reference that */
 /* was handled. (print or change) */
 
-void Cvar_WriteVariables(char *path);
+void Cvar_WriteVariables(const char *path);
 
 /* appends lines containing "set variable value" for all variables */
 /* with the archive flag set to true. */
@@ -590,7 +616,7 @@ qboolean Netchan_CanReliable(netchan_t *chan);
 #include "files.h"
 
 cmodel_t *CM_LoadMap(char *name, qboolean clientload, unsigned *checksum);
-cmodel_t *CM_InlineModel(char *name);       /* *1, *2, etc */
+cmodel_t *CM_InlineModel(const char *name);       /* *1, *2, etc */
 
 int CM_NumClusters(void);
 int CM_NumInlineModels(void);
@@ -675,18 +701,18 @@ int FS_FRead(void *buffer, int size, int count, fileHandle_t f);
 // returns NULL if f is no valid handle
 const char* FS_GetFilenameForHandle(fileHandle_t f);
 
-char **FS_ListFiles(char *findname, int *numfiles,
+char **FS_ListFiles(const char *findname, int *numfiles,
 		unsigned musthave, unsigned canthave);
-char **FS_ListFiles2(char *findname, int *numfiles,
+char **FS_ListFiles2(const char *findname, int *numfiles,
 		unsigned musthave, unsigned canthave);
 void FS_FreeList(char **list, int nfiles);
 
 void FS_InitFilesystem(void);
 void FS_ShutdownFilesystem(void);
-void FS_BuildGameSpecificSearchPath(char *dir);
+void FS_BuildGameSpecificSearchPath(const char *dir);
 char *FS_Gamedir(void);
-char *FS_NextPath(char *prevpath);
-int FS_LoadFile(char *path, void **buffer);
+char *FS_NextPath(const char *prevpath);
+int FS_LoadFile(const char *path, void **buffer);
 qboolean FS_FileInGamedir(const char *file);
 qboolean FS_AddPAKFromGamedir(const char *pak);
 const char* FS_GetNextRawPath(const char* lastRawPath);
@@ -715,11 +741,11 @@ void FS_CreatePath(char *path);
 
 void Com_BeginRedirect(int target, char *buffer, int buffersize, void (*flush)(int, char *));
 void Com_EndRedirect(void);
-void Com_Printf(char *fmt, ...) PRINTF_ATTR(1, 2);
-void Com_DPrintf(char *fmt, ...) PRINTF_ATTR(1, 2);
+void Com_Printf(const char *fmt, ...) PRINTF_ATTR(1, 2);
+void Com_DPrintf(const char *fmt, ...) PRINTF_ATTR(1, 2);
 void Com_VPrintf(int print_level, const char *fmt, va_list argptr); /* print_level is PRINT_ALL or PRINT_DEVELOPER */
-void Com_MDPrintf(char *fmt, ...) PRINTF_ATTR(1, 2);
-YQ2_ATTR_NORETURN void Com_Error(int code, char *fmt, ...) PRINTF_ATTR(2, 3);
+void Com_MDPrintf(const char *fmt, ...) PRINTF_ATTR(1, 2);
+YQ2_ATTR_NORETURN_FUNCPTR void Com_Error(int code, const char *fmt, ...) PRINTF_ATTR(2, 3);
 YQ2_ATTR_NORETURN void Com_Quit(void);
 
 /* Ugly work around for unsupported
@@ -812,7 +838,7 @@ void SV_Frame(int usec);
 // system.c
 char *Sys_ConsoleInput(void);
 void Sys_ConsoleOutput(char *string);
-YQ2_ATTR_NORETURN void Sys_Error(char *error, ...);
+YQ2_ATTR_NORETURN void Sys_Error(const char *error, ...);
 YQ2_ATTR_NORETURN void Sys_Quit(void);
 void Sys_Init(void);
 char *Sys_GetHomeDir(void);
@@ -842,4 +868,6 @@ void Sys_SetupFPU(void);
 
 /* ======================================================================= */
 
+void Mods_NamesFinish(void);
+
 #endif
